---
title: Microsoft Fabric
sidebarTitle: Microsoft Fabric
---

![Fabric Example](img/ecosystem-fabric.png)

[Microsoft Fabric](https://learn.microsoft.com/en-us/fabric/get-started/microsoft-fabric-overview) is an all-in-one analytics solution for enterprises that covers everything from data movement to data science, Real-Time Analytics, and business intelligence. It offers a comprehensive suite of services, including data lake, data engineering, and data integration, all in one place. In this notebook, we give a simple example for using AG2 in Microsoft Fabric.

- [Microsoft Fabric + AG2 Code Examples](https://github.com/ag2ai/ag2/blob/main/notebook/agentchat_microsoft_fabric.ipynb)
